#
# spec file for package liburiparser1
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# build --with=cpptest to run unit tests
%bcond_with cpptest

%define so_ver 1
Name:           uriparser
Version:        0.8.5
Release:        150000.3.8.1
Summary:        A strictly RFC 3986 compliant URI parsing library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://uriparser.github.io
Source:         https://github.com/uriparser/uriparser/archive/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         uriparser-doxygen.patch
Patch1:         CVE-2018-19198.patch
Patch2:         CVE-2018-19200.patch
Patch3:         CVE-2018-19199.patch
Patch4:         CVE-2018-20721.patch
Patch5:         CVE-2024-34402.patch
Patch6:         CVE-2024-34403.patch
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libxdot)
%if %{with cpptest}
BuildRequires:  cpptest-devel > 1.1.0
%endif
Provides:       uriparse = %{version}-%{release}
Obsoletes:      uriparse < %{version}-%{release}

%description
uriparser is a strictly RFC 3986 compliant URI parsing library
and supports Unicode.

There is a command line tool, uriparse, which allows parsing URIs and
show how the liburiparser splits it into components.

%package -n liburiparser%{so_ver}
Summary:        A strictly RFC 3986 compliant URI parsing library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n liburiparser%{so_ver}
uriparser is a strictly RFC 3986 compliant URI parsing library
and supports Unicode.

%package devel
Summary:        Development files for a URI parsing library
License:        BSD-3-Clause and LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       liburiparser%{so_ver} = %{version}
Requires:       glibc-devel
Provides:       liburiparser-devel = %{version}-%{release}
Obsoletes:      liburiparser-devel < %{version}-%{release}

%description devel
uriparser is a strictly RFC 3986 compliant URI parsing library
and supports Unicode.

This subpackage contains the header files for the library.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
#file is dated in the future..
#find . -type f -exec touch {} +
# This is ridiculous but the patch doesn't apply at all for no reasons
sed -i "s|# .qhp output|HTML_TIMESTAMP=NO|g" doc/Doxyfile.in

%build
autoreconf -fiv
%configure \
    --disable-static \
%if ! %{with cpptest}
    --disable-test \
%endif
    --docdir=%{_docdir}/%{name}-devel

make %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}%{_libdir}/*.la
# Currently documentation is useless - revisit at later date
rm -rf %{buildroot}%{_docdir}/%{name}-devel/html

%check
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$((${RANDOM:-256} % 256))
make check || ( cat ./test-suite.log && false )
unset MALLOC_CHECK_ MALLOC_PERTURB_

%post -n liburiparser%{so_ver} -p /sbin/ldconfig

%postun -n liburiparser%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/uriparse

%files -n liburiparser%{so_ver}
%defattr(-,root,root)
%{_libdir}/liburiparser.so.%{so_ver}
%{_libdir}/liburiparser.so.%{so_ver}.*

%files devel
%defattr(-,root,root)
%license COPYING
%doc ChangeLog README.md THANKS TODO.txt GOALS.txt AUTHORS
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/liburiparser.so
%{_libdir}/pkgconfig/liburiparser.pc
# %%{_docdir}/%%{name}-devel/html/*
%dir %{_docdir}/%{name}-devel
#%%dir %%{_docdir}/%%{name}-devel/html

%changelog
* Fri May 17 2024 gus.kenion@suse.com
- CVE-2024-34402.patch: Protect against integer overflow in
  ComposeQueryEngine (bsc#1223887, CVE-2024-34402)
- CVE-2024-34403.patch: Protect against integer overflow in
  ComposeQueryMallocExMm (bsc#1223888, CVE-2024-34403)
* Wed Jan 16 2019 adam.majer@suse.de
- CVE-2018-20721.patch: fix an out-of-bounds read for incomplete
  URIs with IPv6 addresses with embedded IPv4 address
  (bsc#1122193, CVE-2018-20721)
* Fri Nov 16 2018 adam.majer@suse.de
- CVE-2018-19198.patch: fix an out-of-bounds write via a
  uriComposeQuery* or uriComposeQueryEx*
  (bsc#1115722, CVE-2018-19198)
- CVE-2018-19199.patch: fix integer overflow via a uriComposeQuery*
  or uriComposeQueryEx* function (bsc#1115723, CVE-2018-19199)
- CVE-2018-19200.patch: fix attempted operations on NULL input via
  a uriResetUri* function (bsc#1115724, CVE-2018-19200)
- enable unit tests, when cpptest-devel is available
* Wed Feb 21 2018 adam.majer@suse.de
- Package COPYING and other basic documentation
- Drop HTML documentation, for now, since it has no content.
* Wed Feb 21 2018 adam.majer@suse.de
- Fix Group of the library subpackage
* Tue Feb 20 2018 jengelh@inai.de
- Merge subpackage uriparse into uriparser main package,
  and rename liburiparser-devel to uriparser-devel.
* Tue Feb 20 2018 adam.majer@suse.de
- Rename package to comply with openSUSE packaging guidelines
  (bnc#1081686, sr#577196)
- Rename changes and spec file and drop usage of pkg_name
* Tue Feb 13 2018 jengelh@inai.de
- Remove pointless --with-pic (no effect with --disable-static)
- Ensure neutrality of description.
* Thu Feb  8 2018 aloisio@gmx.com
- Update to version 0.8.5
  * Changed: The uriparser project has moved from SourceForge to
    GitHub:
    Code + issue tracker: https://github.com/uriparser/uriparser
    New website: https://uriparser.github.io/
    Please update any links of yours, accordingly. Thank you!
  * Fixed: Memleak in out-of-memory clean-up code
    of URI normalization, related to SF.net bug #28.
    Thanks to Chris Hills for the report!
  * Fixed: Fix compilation of uriparse(1) on FreeBSD
    Thanks to Ed Schouten for the patch!
  * Fixed: Fix C90 compilation errors
    Thanks to Joel Cunningham for the patches!
  * Fixed: Space requirements documented for
    uriWindowsFilenameToUriStringA
    given URI "file://server1/file1.txt" (SF.net bug #31)
    Thanks to threedyd for the report!
  * Fixed: Compiler warnings
    Thanks to Joel Cunningham for the patches!
  * Fixed: Stop exporting internal function RemoveBaseUriImpl
    Thanks to Joel Cunningham for the report!
  * Fixed: API documentation front page no longer empty with
    Doxygen 1.8.13
  * Fixed: "make -C doc install" fixed for lack of .map files
  * Improved: Communicate that absolutePath is always URI_FALSE
    for URIs with a host in uriparse CLI tool output and Uri.h
    header
    (GitHub #2, SF.net #30)
  * Soname: 1:21:0
  version 0.8.4
  * Fixed: Stack overflow on parsing malformed IPv6 addresses with
    more than eigtht quads.  Thanks to Alexander Klink for the
    report!
  * Soname: 1:20:0
  version 0.8.3
  * Fixed: uriCompareRange reported NULL pointer and range of
    length zero as equal, by mistake.
    Thanks to Robert Kausch and his Coverity report.
  * Fixed: Use-after-free in out-of-memory code of uriMakeOwner.
    Thanks to Chris Hills and his Klocwork-based report (SF.net
    bug #28)
  * Soname: 1:19:0
  version 0.8.2
  * Fixed: Broken conversion from/to Windows network shares
    (SF.net bug #21)
    Thanks to Adam Gross and Dmitry Repkin!
  * Fixed: Limit uriCompareRange return values to -1/0/1 (SF.net
    bug #24)
    As a side effect, this fixes the test suite for AArch64.
    Thanks to Marcin Juszkiewicz for the patch!
  * Fixed: MinGW Makefile:
    LIB_DIR fixed from ../../lib leftover to ../../src (SF.net
    bug #27)
    Thanks to Dmytro Zagashev for the report!
  * Fixed: Add missing NULL checks to UriStringToFilename (SF.net
    bug #25)
    Thanks to Jerome Custodio for the report!
  * Changed: Leave inlining decisions to GCC
  * Soname: 1:18:0
- Refreshed uriparser-doxygen.patch
- Spec cleanup
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.8.1
  * Fixed: Sync URI_VER_* preprocessor defines (were at 0.7.6, bug #23)
  * Fixed: Bug in internal function that may flip uriEqualsUri results around
  * Added: Function uriAddBaseUriEx allowing to resolve URIs with
    a scheme identical to that of the base URI to resolve against
    as if the URI to resolve had no scheme specified, when flag
    URI_RESOLVE_IDENTICAL_SCHEME_COMPAT is specified (feature request #4)
  * Soname: 1:17:0
- Update uriparser-0.7.5-doxygen.patch
  > uriparser-doxygen.patch
- Add pkgconfig(libxdot) require; new upstream dependency
- Update download source Url to current sourceforge location
- Split out uriparse binary into his own package
* Tue May 27 2014 crrodriguez@opensuse.org
- Extend uriparser-0.7.5-doxygen.patch so doxygen does not
  generate timestamped files.
* Sun Feb  3 2013 coolo@suse.com
- update license to new format
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
* Mon Sep  6 2010 coolo@novell.com
- fix compile, newer doxygen does not use .gif anymore
* Fri Apr  9 2010 davejplater@gmail.com
- Update to version 0.7.5 fixed doxygen build with uriparser-0.7.5-doxygen.patch
- Upstream changes :-
  * Added: pkg-config file
  * Fixed: File Doxyfile.in was missing from release archives
    Thanks to Rakesh Pandit for reporting!
  * Fixed: Doc generation troubles
  * Changed: No longer shipping bundled libcpptest
  * Changed: New dependencies:
  - libcpptest 1.1.0 or later
  - pkg-config (for libcpptest detection)
    Both dependencies can be disable through configuring
    with --disable-test, which excludes the test suite
    from compilation.
  * Soname: 1:10:0
* Sun Sep  6 2009 meissner@suse.de
- use correct version in .spec file, removed unnecessary CFLAGS/CXXFLAGS
  stuff now default.
* Tue Dec 23 2008 pascal.bleser@opensuse.org
- update to version 0.7.4:
  * fixes null pointer de-referencing and memory leaks in two places
- changes from 0.7.3:
  * fixes a small bug with parsing
* Sun Sep  7 2008 schwab@suse.de
- Remove conflicting libtool macros.
* Tue Sep  2 2008 crrodriguez@suse.de
- update to version 0.7.2
  Fixed: Bad cleanup logic in functions
  uriAddBaseUri(..)
    uriRemoveBaseUri(..)
    Previously you needed to call uriFreeUriMembers on return code
    URI_ERROR_MALLOC and only then. So that's why these functions now
    take cleanup off your shoulders. An extra call to uriFreeUriMembers
    from your side is still needed in case of success.
  * Soname: 1:7:0
* Mon Apr 28 2008 crrodriguez@suse.de
- update to version 0.7.1
  * Fixed: Bogus syntax error when parsing URIs with port-like
    passwords, e.g. "http://user:21@host/" (#1948038)
    Thanks to Friedrich Delgado Friedrichs for reporting!
  * Fixed: Parser did not handle trailing slashes correctly in some cases,
    which also made the structures produced from parsing "http://e.com/"
    and "http://e.com" indistinguishable. (#1950126)
    Thanks to Edward Z. Yang for reporting!
* Fri Apr  4 2008 crrodriguez@suse.de
- update to version 0.7.0
  * Added: Dissection and composition of query strings
  * Added: Documentation improvements
    (in|out|inout indicators, addition of \since and \see)
  * Changed: Code::Blocks project files updated from file format
    version 1.4 to 1.6, which is produced by Code::Blocks 8.02
  * Added: Code::Blocks workspace file
  * Changed: Soname set to 1:5:0
* Tue Mar 11 2008 crrodriguez@suse.de
- fix buildRequires
* Mon Feb 25 2008 crrodriguez@suse.de
- version 0.6.4
  * Added: Syntax-based normalization can now handle relative URIs,
    e.g. "../../a/b/.././c" is normalized to "../../a/c"
  * Fixed: Normalization code could free foreign memory
  * Fixed: Normalization processed the path segment even when asked not to
  * Fixed: Documentation bug not requiring enough memory for the output
    buffer when converting a relative file URI back to a filename
  * Changed: Soname set to 1:4:0
* Mon Feb 11 2008 crrodriguez@suse.de
- version 0.6.3
- Fixed: Two major crash bugs in normalization code
- Added: Brief usage tutorial
- Changed: Soname set to 1:3:0
* Mon Feb  4 2008 crrodriguez@suse.de
- version 0.6.1
* Thu Oct 18 2007 crrodriguez@suse.de
- update to version 0.6.0 , liburiparse1
* Wed Aug 15 2007 crrodriguez@suse.de
- first package for the OBS
